@@ -1,4 +1,5 @@
 import json
+import logging
 import re
 from copy import deepcopy
 
@@ -6,6 +7,7 @@ from localstack.aws.api import RequestContext, ServiceRequest, handler
 from localstack.aws.api.apigateway import (
     Account,
     ApigatewayApi,
+    ApiKeys,
     Authorizer,
     Authorizers,
     BasePathMapping,
@@ -19,11 +21,13 @@ from localstack.aws.api.apigateway import (
     DocumentationPart,
     DocumentationPartLocation,
     DocumentationParts,
+    ExportResponse,
     GetDocumentationPartsRequest,
     ListOfPatchOperation,
     ListOfString,
     MapOfStringToString,
     NotFoundException,
+    NullableBoolean,
     NullableInteger,
     PutRestApiRequest,
     RequestValidator,
@@ -36,7 +40,7 @@ from localstack.aws.api.apigateway import (
 )
 from localstack.aws.forwarder import create_aws_request_context
 from localstack.aws.proxy import AwsApiListener
-from localstack.constants import HEADER_LOCALSTACK_EDGE_URL
+from localstack.constants import APPLICATION_JSON, HEADER_LOCALSTACK_EDGE_URL
 from localstack.services.apigateway import helpers
 from localstack.services.apigateway.context import ApiInvocationContext
 from localstack.services.apigateway.helpers import (
@@ -44,6 +48,7 @@ from localstack.services.apigateway.helpers import (
     PATH_REGEX_TEST_INVOKE_API,
     PATH_REGEX_USER_REQUEST,
     APIGatewayRegion,
+    OpenApiExporter,
     apply_json_patch_safe,
     find_api_subentity_by_id,
 )
@@ -54,11 +59,13 @@ from localstack.services.plugins import ServiceLifecycleHook
 from localstack.utils.analytics import event_publisher
 from localstack.utils.aws import aws_stack
 from localstack.utils.aws.aws_responses import requests_response
-from localstack.utils.collections import ensure_list
+from localstack.utils.collections import PaginatedList, ensure_list
 from localstack.utils.json import parse_json_or_yaml
 from localstack.utils.strings import short_uid, str_to_bool, to_str
 from localstack.utils.time import now_utc
 
+LOG = logging.getLogger(__name__)
+
 
 class ApigatewayApiListener(AwsApiListener):
     """Custom API listener that handles both, API Gateway API calls (managing the
@@ -74,35 +81,37 @@ class ApigatewayApiListener(AwsApiListener):
                 return result
 
         if helpers.is_test_invoke_method(method, path):
-            # if call is from test_invoke_api then use http_method to find the integration,
-            #   as test_invoke_api makes a POST call to request the test invocation
-            match = re.match(PATH_REGEX_TEST_INVOKE_API, path)
-            invocation_context.method = match[3]
-            data = parse_json_or_yaml(to_str(data or b""))
-            if data:
-                orig_data = data
-                path_with_query_string = orig_data.get("pathWithQueryString", None)
-                if path_with_query_string:
-                    invocation_context.path_with_query_string = path_with_query_string
-                invocation_context.data = data.get("body")
-                invocation_context.headers = orig_data.get("headers", {})
-            result = invoke_rest_api_from_request(invocation_context)
-            result = {
-                "status": result.status_code,
-                "body": to_str(result.content),
-                "headers": dict(result.headers),
-            }
-            return result
-
+            return self._handle_test_invoke_method(invocation_context)
         return super().forward_request(method, path, data, headers)
 
+    def _handle_test_invoke_method(self, invocation_context):
+        # if call is from test_invoke_api then use http_method to find the integration,
+        #   as test_invoke_api makes a POST call to request the test invocation
+        match = re.match(PATH_REGEX_TEST_INVOKE_API, invocation_context.path)
+        invocation_context.method = match[3]
+        if data := parse_json_or_yaml(to_str(invocation_context.data or b"")):
+            orig_data = data
+            if path_with_query_string := orig_data.get("pathWithQueryString", None):
+                invocation_context.path_with_query_string = path_with_query_string
+            invocation_context.data = data.get("body")
+            invocation_context.headers = orig_data.get("headers", {})
+        result = invoke_rest_api_from_request(invocation_context)
+        result = {
+            "status": result.status_code,
+            "body": to_str(result.content),
+            "headers": dict(result.headers),
+        }
+        return result
+
     def return_response(self, method, path, data, headers, response):
         # TODO: clean up logic below!
 
         # fix backend issue (missing support for API documentation)
-        if re.match(r"/restapis/[^/]+/documentation/versions", path):
-            if response.status_code == 404:
-                return requests_response({"position": "1", "items": []})
+        if (
+            re.match(r"/restapis/[^/]+/documentation/versions", path)
+            and response.status_code == 404
+        ):
+            return requests_response({"position": "1", "items": []})
 
         # keep track of API regions for faster lookup later on
         # TODO - to be removed - see comment for API_REGIONS variable
@@ -127,7 +136,14 @@ class ApigatewayProvider(ApigatewayApi, ServiceLifecycleHook):
         return result
 
     def delete_rest_api(self, context: RequestContext, rest_api_id: String) -> None:
-        call_moto(context)
+        try:
+            call_moto(context)
+        except KeyError as e:
+            # moto raises a key error if we're trying to delete an API that doesn't exist
+            raise NotFoundException(
+                f"Invalid API identifier specified {context.account_id}:{rest_api_id}"
+            ) from e
+
         event_publisher.fire_event(
             event_publisher.EVENT_APIGW_DELETE_API,
             payload={"a": event_publisher.get_hash(rest_api_id)},
@@ -675,6 +691,55 @@ class ApigatewayProvider(ApigatewayApi, ServiceLifecycleHook):
         except Exception as e:
             raise NotFoundException("Invalid Resource identifier specified") from e
 
+    def get_export(
+        self,
+        context: RequestContext,
+        rest_api_id: String,
+        stage_name: String,
+        export_type: String,
+        parameters: MapOfStringToString = None,
+        accepts: String = None,
+    ) -> ExportResponse:
+
+        openapi_exporter = OpenApiExporter()
+        result = openapi_exporter.export_api(
+            api_id=rest_api_id, stage=stage_name, export_type=export_type, export_format=accepts
+        )
+
+        if accepts == APPLICATION_JSON:
+            result = json.dumps(result, indent=2)
+
+        return ExportResponse(contentType=accepts, body=result)
+
+    def get_api_keys(
+        self,
+        context: RequestContext,
+        position: String = None,
+        limit: NullableInteger = None,
+        name_query: String = None,
+        customer_id: String = None,
+        include_values: NullableBoolean = None,
+    ) -> ApiKeys:
+        moto_response: ApiKeys = call_moto(context=context)
+        item_list = PaginatedList(moto_response["items"])
+
+        def token_generator(item):
+            return item["id"]
+
+        def filter_function(item):
+            return item["name"].startswith(name_query)
+
+        paginated_list, next_token = item_list.get_page(
+            token_generator=token_generator,
+            next_token=position,
+            page_size=limit,
+            filter_function=filter_function if name_query else None,
+        )
+
+        return ApiKeys(
+            items=paginated_list, warnings=moto_response.get("warnings"), position=next_token
+        )
+
 
 # ---------------
 # UTIL FUNCTIONS
