@@ -37,6 +37,7 @@ from localstack.aws.api.sqs import (
     Integer,
     InvalidAttributeName,
     InvalidMessageContents,
+    ListDeadLetterSourceQueuesResult,
     ListQueuesResult,
     ListQueueTagsResult,
     Message,
@@ -48,6 +49,7 @@ from localstack.aws.api.sqs import (
     PurgeQueueInProgress,
     QueueAttributeMap,
     QueueAttributeName,
+    QueueDeletedRecently,
     QueueDoesNotExist,
     ReceiptHandleIsInvalid,
     ReceiveMessageResult,
@@ -84,6 +86,10 @@ FIFO_MSG_REGEX = "^[0-9a-zA-z!\"#$%&'()*+,./:;<=>?@[\\]^_`{|}~-]*$"
 
 DEDUPLICATION_INTERVAL_IN_SEC = 5 * 60
 
+# When you delete a queue, you must wait at least 60 seconds before creating a queue with the same name.
+# see https://docs.aws.amazon.com/AWSSimpleQueueService/latest/APIReference/API_DeleteQueue.html
+RECENTLY_DELETED_TIMEOUT = 60
+
 
 class InvalidParameterValue(CommonServiceException):
     def __init__(self, message):
@@ -161,6 +167,8 @@ class SqsMessage:
     visibility_timeout: int
     receive_times: int
     receipt_handles: Set[str]
+    last_received: Optional[float]
+    first_received: Optional[float]
     deleted: bool
     priority: float
     message_deduplication_id: str
@@ -302,8 +310,8 @@ class SqsQueue:
             scheme = context.request.scheme
             host_url = f"{scheme}://{region}queue.{constants.LOCALHOST_HOSTNAME}:{config.EDGE_PORT}"
         elif config.SQS_ENDPOINT_STRATEGY == "path":
-            # localhost:4566/queue/us-east-1/00000000000/my-queue (us-east-1)
-            host_url = f"{context.request.host}/queue/{self.region}"
+            # https?://localhost:4566/queue/us-east-1/00000000000/my-queue (us-east-1)
+            host_url = f"{context.request.host_url}/queue/{self.region}"
         else:
             if config.SQS_PORT_EXTERNAL:
                 host_url = external_service_url("sqs")
@@ -442,7 +450,7 @@ class SqsQueue:
             ] = str(standard_message.receive_times)
             copied_message.message["Attributes"][
                 MessageSystemAttributeName.ApproximateFirstReceiveTimestamp
-            ] = standard_message.first_received
+            ] = str(int(standard_message.first_received * 1000))
             copied_message.message["ReceiptHandle"] = receipt_handle
 
             return copied_message
@@ -706,9 +714,16 @@ def check_fifo_id(fifo_id):
 
 class SqsBackend(RegionBackend):
     queues: Dict[str, SqsQueue]
+    deleted: Dict[str, float]
 
     def __init__(self):
         self.queues = {}
+        self.deleted = {}
+
+    def expire_deleted(self):
+        for k in list(self.deleted.keys()):
+            if self.deleted[k] <= (time.time() - RECENTLY_DELETED_TIMEOUT):
+                del self.deleted[k]
 
 
 class SqsProvider(SqsApi, ServiceLifecycleHook):
@@ -791,18 +806,31 @@ class SqsProvider(SqsApi, ServiceLifecycleHook):
 
         backend = SqsBackend.get(context.region)
 
-        if queue_name in backend.queues:
-            # FIXME #5938: should raise `QueueNameExists` if queue exists with different attributes
-            queue = backend.queues[queue_name]
-            return CreateQueueResult(QueueUrl=queue.url(context))
-        if fifo:
-            queue = FifoQueue(queue_name, context.region, context.account_id, attributes, tags)
-        else:
-            queue = StandardQueue(queue_name, context.region, context.account_id, attributes, tags)
-
-        LOG.debug("creating queue key=%s attributes=%s tags=%s", queue_name, attributes, tags)
-
         with self._mutex:
+            if queue_name in backend.queues:
+                # FIXME #5938: should raise `QueueNameExists` if queue exists with different attributes
+                queue = backend.queues[queue_name]
+                return CreateQueueResult(QueueUrl=queue.url(context))
+
+            if config.SQS_DELAY_RECENTLY_DELETED:
+                deleted = backend.deleted.get(queue_name)
+                if deleted and deleted > (time.time() - RECENTLY_DELETED_TIMEOUT):
+                    raise QueueDeletedRecently(
+                        "You must wait 60 seconds after deleting a queue before you can create "
+                        "another with the same name."
+                    )
+            backend.expire_deleted()
+
+            # create the appropriate queue
+            if fifo:
+                queue = FifoQueue(queue_name, context.region, context.account_id, attributes, tags)
+            else:
+                queue = StandardQueue(
+                    queue_name, context.region, context.account_id, attributes, tags
+                )
+
+            LOG.debug("creating queue key=%s attributes=%s tags=%s", queue_name, attributes, tags)
+
             backend.queues[queue_name] = queue
 
         return CreateQueueResult(QueueUrl=queue.url(context))
@@ -896,6 +924,7 @@ class SqsProvider(SqsApi, ServiceLifecycleHook):
         with self._mutex:
             queue = self._resolve_queue(context, queue_url=queue_url)
             del backend.queues[queue.name]
+            backend.deleted[queue.name] = time.time()
 
     def get_queue_attributes(
         self, context: RequestContext, queue_url: String, attribute_names: AttributeNameList = None
@@ -1140,6 +1169,25 @@ class SqsProvider(SqsApi, ServiceLifecycleHook):
         else:
             return False
 
+    def list_dead_letter_source_queues(
+        self,
+        context: RequestContext,
+        queue_url: String,
+        next_token: Token = None,
+        max_results: BoxedInteger = None,
+    ) -> ListDeadLetterSourceQueuesResult:
+        urls = []
+        backend = SqsBackend.get(context.region)
+        dead_letter_queue = self._resolve_queue(context, queue_url=queue_url)
+        for queue in backend.queues.values():
+            policy = queue.attributes.get(QueueAttributeName.RedrivePolicy)
+            if policy:
+                policy = json.loads(policy)
+                dlq_arn = policy.get("deadLetterTargetArn")
+                if dlq_arn == dead_letter_queue.arn:
+                    urls.append(queue.url(context))
+        return ListDeadLetterSourceQueuesResult(queueUrls=urls)
+
     def delete_message(
         self, context: RequestContext, queue_url: String, receipt_handle: String
     ) -> None:
@@ -1287,7 +1335,7 @@ class SqsProvider(SqsApi, ServiceLifecycleHook):
     ) -> Dict[MessageSystemAttributeName, str]:
         result: Dict[MessageSystemAttributeName, str] = {
             MessageSystemAttributeName.SenderId: context.account_id,  # not the account ID in AWS
-            MessageSystemAttributeName.SentTimestamp: str(now()),
+            MessageSystemAttributeName.SentTimestamp: str(now(millis=True)),
         }
 
         if message_system_attributes is not None:
