@@ -14,6 +14,7 @@ import botocore.session
 import pytest
 from _pytest.config import Config
 from _pytest.nodes import Item
+from botocore.exceptions import ClientError
 from botocore.regions import EndpointResolver
 
 from localstack import config
@@ -317,8 +318,38 @@ def route53_client() -> "Route53Client":
     return _client("route53")
 
 
+@pytest.fixture
+def dynamodb_create_table_with_parameters(dynamodb_client):
+    tables = []
+
+    def factory(**kwargs):
+        if "TableName" not in kwargs:
+            kwargs["TableName"] = "test-table-%s" % short_uid()
+
+        tables.append(kwargs["TableName"])
+        return dynamodb_client.create_table(**kwargs)
+
+    yield factory
+
+    # cleanup
+    for table in tables:
+        try:
+            # table has to be in ACTIVE state before deletion
+            def wait_for_table_created():
+                return (
+                    dynamodb_client.describe_table(TableName=table)["Table"]["TableStatus"]
+                    == "ACTIVE"
+                )
+
+            poll_condition(wait_for_table_created, timeout=30)
+            dynamodb_client.delete_table(TableName=table)
+        except Exception as e:
+            LOG.debug("error cleaning up table %s: %s", table, e)
+
+
 @pytest.fixture
 def dynamodb_create_table(dynamodb_client):
+    # beware, this swallows exception in create_dynamodb_table utility function
     tables = []
 
     def factory(**kwargs):
@@ -425,6 +456,25 @@ def sqs_queue_arn(sqs_client):
     return _get_arn
 
 
+@pytest.fixture
+def sqs_queue_exists(sqs_client):
+    def _queue_exists(queue_url: str) -> bool:
+        """
+        Checks whether a queue with the given queue URL exists.
+        :param queue_url: the queue URL
+        :return: true if the queue exists, false otherwise
+        """
+        try:
+            result = sqs_client.get_queue_url(QueueName=queue_url.split("/")[-1])
+            return result.get("QueueUrl") == queue_url
+        except ClientError as e:
+            if "NonExistentQueue" in e.response["Error"]["Code"]:
+                return False
+            raise
+
+    yield _queue_exists
+
+
 @pytest.fixture
 def sns_create_topic(sns_client):
     topic_arns = []
@@ -751,6 +801,7 @@ def deploy_cfn_template(
             StackName=stack_name,
             ChangeSetName=change_set_name,
             TemplateBody=template_rendered,
+            Capabilities=["CAPABILITY_AUTO_EXPAND", "CAPABILITY_IAM", "CAPABILITY_NAMED_IAM"],
             ChangeSetType=("UPDATE" if is_update else "CREATE"),
             Parameters=[
                 {
@@ -935,10 +986,10 @@ role_policy = """
 
 
 @pytest.fixture
-def create_lambda_function(lambda_client, iam_client, wait_until_lambda_ready):
+def create_lambda_function(lambda_client, logs_client, iam_client, wait_until_lambda_ready):
     lambda_arns = []
-    role_names = []
-    policy_arns = []
+    role_names_policy_arns = []
+    log_groups = []
 
     def _create_lambda_function(*args, **kwargs):
         kwargs["client"] = lambda_client
@@ -948,7 +999,6 @@ def create_lambda_function(lambda_client, iam_client, wait_until_lambda_ready):
 
         if not kwargs.get("role"):
             role_name = f"lambda-autogenerated-{short_uid()}"
-            role_names.append(role_name)
             role = iam_client.create_role(
                 RoleName=role_name, AssumeRolePolicyDocument=role_assume_policy
             )["Role"]
@@ -956,7 +1006,7 @@ def create_lambda_function(lambda_client, iam_client, wait_until_lambda_ready):
             policy_arn = iam_client.create_policy(
                 PolicyName=policy_name, PolicyDocument=role_policy
             )["Policy"]["Arn"]
-            policy_arns.append(policy_arn)
+            role_names_policy_arns.append((role_name, policy_arn))
             iam_client.attach_role_policy(RoleName=role_name, PolicyArn=policy_arn)
             kwargs["role"] = role["Arn"]
 
@@ -964,6 +1014,8 @@ def create_lambda_function(lambda_client, iam_client, wait_until_lambda_ready):
             resp = testutil.create_lambda_function(func_name, **kwargs)
             lambda_arns.append(resp["CreateFunctionResponse"]["FunctionArn"])
             wait_until_lambda_ready(function_name=func_name)
+            log_group_name = f"/aws/lambda/{func_name}"
+            log_groups.append(log_group_name)
             return resp
 
         # @AWS, takes about 10s until the role/policy is "active", until then it will fail
@@ -978,18 +1030,23 @@ def create_lambda_function(lambda_client, iam_client, wait_until_lambda_ready):
         except Exception:
             LOG.debug(f"Unable to delete function {arn=} in cleanup")
 
-    for role_name in role_names:
+    for role_name, policy_arn in role_names_policy_arns:
         try:
+            iam_client.detach_role_policy(RoleName=role_name, PolicyArn=policy_arn)
             iam_client.delete_role(RoleName=role_name)
         except Exception:
             LOG.debug(f"Unable to delete role {role_name=} in cleanup")
-
-    for policy_arn in policy_arns:
         try:
             iam_client.delete_policy(PolicyArn=policy_arn)
         except Exception:
             LOG.debug(f"Unable to delete policy {policy_arn=} in cleanup")
 
+    for log_group_name in log_groups:
+        try:
+            logs_client.delete_log_group(logGroupName=log_group_name)
+        except Exception:
+            LOG.debug(f"Unable to delete log group {log_group_name} in cleanup")
+
 
 @pytest.fixture
 def check_lambda_logs(logs_client):
